@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
-# Copyright (C) 2005 Piotr Macuk <piotr@macuk.pl>
-# Copyright (C) 2006-2007 Juan David Ibáñez Palomar <jdavid@itaapy.com>
+# Copyright (C) 2006-2008 Juan David Ibáñez Palomar <jdavid@itaapy.com>
+# Copyright (C) 2008 Nicolas Deram <nicolas@itaapy.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,8 +20,10 @@ from mimetypes import add_type
 
 # Import from itools
 from csv_ import CSVFile, Row
+from memory import MemoryCatalog
 from parser import parse
-from table import Table, parse_table, fold_line, escape_data, Record, Property
+from table import Table, Record, Property, UniqueError
+from table import parse_table, fold_line, escape_data, is_multilingual
 
 
 __all__ = [
@@ -30,13 +32,16 @@ __all__ = [
     # Classes
     'CSVFile',
     'Row',
+    'MemoryCatalog',
     # The Table handler (a kind of CSV on steroids)
     'Table',
     'Record',
     'Property',
+    'UniqueError',
     'parse_table',
     'fold_line',
     'escape_data',
+    'is_multilingual',
     ]
 
 
