@@ -809,13 +809,15 @@ class Table(File):
             # Default
             if property is None:
                 return datatype.get_default()
-            # Language negotiation ('select_language' must be available)
+            # Language negotiation ('select_language' is a built-in)
             if language is None:
                 languages = [ x.parameters['language'] for x in property ]
                 language = select_language(languages)
+                if language is None and languages:
+                    # Pick up one at random (FIXME)
+                    language = languages[0]
             # Miss: default
             if language is None:
-                # XXX Should send any value?
                 return datatype.get_default()
             # Hit
             for x in property:
