@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright (C) 2005-2007 Juan David Ibáñez Palomar <jdavid@itaapy.com>
+# Copyright (C) 2005-2008 Juan David Ibáñez Palomar <jdavid@itaapy.com>
 # Copyright (C) 2007 Hervé Cauwelier <herve@itaapy.com>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -24,7 +24,7 @@ from itools.handlers import File, register_handler_class
 
 class MOFile(File):
 
-    class_mimetypes = ['application/x-mo']
+    class_mimetypes = ['application/x-gettext-translation']
     class_extension = 'mo'
 
     def _load_state_from_file(self, file):
