@@ -21,6 +21,8 @@
 
 # Import from itools
 from itools.utils import freeze
+
+# Internal import
 from utils import font_value, format_size, get_color_as_hexa
 from utils import get_color, get_int_value
 
@@ -62,7 +64,7 @@ BODY_MARGINS = {'margin-top': 'topMargin',
 
 
 
-def get_align(attributes):
+def table_get_align(attributes):
     attrs = {}
     hAlign = attributes.get((None, 'align'), None)
     if hAlign in H_ALIGN:
@@ -73,6 +75,36 @@ def get_align(attributes):
     return attrs
 
 
+def table_get_margin(style_css):
+    """Calculate and return top and bottom margin"""
+    margin_top = margin_bottom = None, None
+    for key, value in style_css.iteritems():
+        if key == 'margin-top':
+            margin_top = format_size(value, None)
+        elif key == 'margin-bottom':
+            margin_bottom = format_size(value, None)
+
+    return margin_top, margin_bottom
+
+
+def attribute_style_to_dict(value):
+    """Build a dictionary from a HTML "style" attribute string
+    INPUT: background: red; color: green;
+    OUTPUT: {'background': 'red', 'color': 'green'}"""
+
+    css = {}
+    for data in value.split(';'):
+        if not data:
+            continue
+        try:
+            key, value = data.split(':')
+        except ValueError:
+            continue
+        css[key.strip()] = value.strip()
+    return css
+
+
+
 #######################################################################
 # FONT
 #######################################################################
@@ -364,9 +396,6 @@ def body_margin_style(key, value):
 def build_frame_style(context, style_css, inline_attributes=freeze({})):
     frame_attr = {}
     border = {}
-    # The default style is Normal
-    parent_style_name = 'Normal'
-    bulletText = None
 
     keys = style_css.keys()
     keys.sort()
@@ -555,12 +584,7 @@ def get_table_style(style_css, attributes, start, stop):
     for key1, value in attributes.iteritems():
         key1 = key1[1]
         if key1 == 'style':
-            style_css2 = {}
-            for data in value.split(';'):
-                if not data:
-                    continue
-                key, value = data.split(':') # FIXME to do more robust
-                style_css2[key] = value
+            style_css2 = attribute_style_to_dict(value)
             table_style.extend(_get_table_style(style_css, start, stop))
             border_css_buffer.update(_get_table_style_border_only(style_css2,
                                                                   start, stop))
