@@ -93,6 +93,10 @@ class Authority(object):
         return str(self) == str(other)
 
 
+    def __ne__(self, other):
+        return str(self) != str(other)
+
+
     def __hash__(self):
         return hash(str(self))
 
@@ -363,8 +367,7 @@ class Path(list):
 # XXX The Python functions 'cgi.parse_qs' and 'urllib.urlencode' provide
 # similar functionality, maybe we should just be a thin wrapper around
 # them.
-
-def decode_query(data):
+def decode_query(data, schema=None):
     """Decodes a query as defined by the "application/x-www-form-urlencoded"
     content type.
 
@@ -376,6 +379,9 @@ def decode_query(data):
     """
     query = {}
     if data:
+        if schema is None:
+            schema = {}
+
         for x in data.split('&'):
             if x:
                 if '=' in x:
@@ -385,6 +391,9 @@ def decode_query(data):
                     key, value = x, None
 
                 key = unquote_plus(key)
+                datatype = schema.get(key)
+                if datatype is not None:
+                    value = datatype.decode(value)
                 if key in query:
                     old_value = query[key]
                     if isinstance(old_value, list):
@@ -397,7 +406,8 @@ def decode_query(data):
     return query
 
 
-def encode_query(query):
+
+def encode_query(query, schema=None):
     """This method encodes a query as defined by the
     "application/x-www-form-urlencoded" content type (see
     http://www.w3.org/TR/REC-html40/interact/forms.html#h-17.13.4.1 for
@@ -406,25 +416,37 @@ def encode_query(query):
     The value expected is a dictonary like {'a': 1, 'b': 2}.
     The value returned is a byte string like "a=1&b=2".
     """
+    if schema is None:
+        schema = {}
+
     line = []
-    for key, value in query.items():
+    for key in query:
+        value = query[key]
         key = quote_plus(key)
+
+        # XXX As of the application/x-www-form-urlencoded content type,
+        # it has not sense to have a parameter without a value, so
+        # "?a&b=1" should be the same as "?b=1" (check the spec).
+        # But for the tests defined by RFC2396 to pass, we must preserve
+        # these empty parameters.
         if value is None:
-            # XXX As of the application/x-www-form-urlencoded content type,
-            # it has not sense to have a parameter without a value, so
-            # "?a&b=1" should be the same as "?b=1" (check the spec).
-            # But for the tests defined by RFC2396 to pass, we must preserve
-            # these empty parameters.
             line.append(key)
-        elif isinstance(value, list):
+            continue
+
+        # A list
+        datatype = schema.get(key)
+        if isinstance(value, list):
             for x in value:
-                if isinstance(x, unicode):
-                    x = x.encode('UTF-8')
+                if datatype is not None:
+                    x = datatype.encode(x)
                 line.append('%s=%s' % (key, quote_plus(x)))
-        else:
-            if isinstance(value, unicode):
-                value = value.encode('UTF-8')
-            line.append('%s=%s' % (key, quote_plus(value)))
+            continue
+
+        # A singleton
+        if datatype is not None:
+            value = datatype.encode(value)
+        line.append('%s=%s' % (key, quote_plus(value)))
+
     return '&'.join(line)
 
 
@@ -490,6 +512,10 @@ class Reference(object):
         return str(self) == str(other)
 
 
+    def __ne__(self, other):
+        return str(self) != str(other)
+
+
     def __hash__(self):
         return hash(str(self))
 
@@ -607,11 +633,22 @@ class Reference(object):
         query = copy(self.query)
         for key in kw:
             value = kw[key]
+            # If value is 'None', remove the key
             if value is None:
                 if key in query:
                     del query[key]
-            else:
-                query[key] = value
+                continue
+            # Coerce
+            value_type = type(value)
+            if value_type is int:
+                value = str(value)
+            elif value_type is unicode:
+                value = value.encode('utf-8')
+            elif value_type is not str:
+                raise TypeError, 'unexepected %s value' % type
+            # Update
+            query[key] = value
+        # Ok
         return Reference(self.scheme, self.authority, self.path, query,
                          self.fragment)
 
